@@ -3,6 +3,7 @@ package query
 import (
 	"context"
 	"fmt"
+
 	"github.com/spf13/viper"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/export"
@@ -15,11 +16,6 @@ import (
 type InitData struct {
 	initialisation.InitData
 
-	// the current state that init is in
-	Status string
-	// if non-nil, this is called everytime the status changes
-	OnStatusChanged func(string)
-
 	cancelInitialisation context.CancelFunc
 	Loaded               chan struct{}
 	// map of query name to resolved query (key is the query text for command line queries)
@@ -39,13 +35,6 @@ func NewInitData(ctx context.Context, args []string) *InitData {
 	return i
 }
 
-func (i *InitData) SetStatus(newStatus string) {
-	i.Status = newStatus
-	if i.OnStatusChanged != nil {
-		i.OnStatusChanged(newStatus)
-	}
-}
-
 func queryExporters() []export.Exporter {
 	return []export.Exporter{&export.SnapshotExporter{}}
 }
@@ -77,17 +66,13 @@ func (i *InitData) Cleanup(ctx context.Context) {
 	}
 }
 
-func (i *InitData) init(parentCtx context.Context, args []string) {
+func (i *InitData) init(ctx context.Context, args []string) {
 	defer func() {
 		close(i.Loaded)
 		// clear the cancelInitialisation function
 		i.cancelInitialisation = nil
 	}()
 
-	// create a context with the init hook in - which can be sent down to lower level operations
-	hook := NewQueryInitStatusHook(i)
-	ctx := statushooks.AddStatusHooksToContext(parentCtx, hook)
-
 	// validate export args
 	if len(viper.GetStringSlice(constants.ArgExport)) > 0 {
 		i.RegisterExporters(queryExporters()...)
@@ -114,7 +99,7 @@ func (i *InitData) init(parentCtx context.Context, args []string) {
 	statushooks.SetStatus(ctx, "Resolving arguments")
 
 	// convert the query or sql file arg into an array of executable queries - check names queries in the current workspace
-	resolvedQueries, preparedStatementSource, err := w.GetQueriesFromArgs(args)
+	resolvedQueries, err := w.GetQueriesFromArgs(args)
 	if err != nil {
 		i.Result.Error = err
 		return
@@ -124,9 +109,7 @@ func (i *InitData) init(parentCtx context.Context, args []string) {
 	// and store it
 	i.cancelInitialisation = cancel
 	i.Queries = resolvedQueries
-	i.PreparedStatementSource = preparedStatementSource
 
 	// and call base init
 	i.InitData.Init(ctx, constants.InvokerQuery)
-
 }
