@@ -7,7 +7,7 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/Masterminds/semver"
+	"github.com/Masterminds/semver/v3"
 	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe-plugin-sdk/v5/plugin"
@@ -21,60 +21,69 @@ import (
 // if CreatePseudoResources flag is set, construct hcl resources for files with specific extensions
 // NOTE: it is an error if there is more than 1 mod defined, however zero mods is acceptable
 // - a default mod will be created assuming there are any resource files
-func LoadMod(modPath string, parseCtx *parse.ModParseContext) (mod *modconfig.Mod, errAndWarnings *modconfig.ErrorAndWarnings) {
+func LoadMod(modPath string, parseCtx *parse.ModParseContext, opts ...LoadModOption) (mod *modconfig.Mod, errorsAndWarnings *modconfig.ErrorAndWarnings) {
 	defer func() {
 		if r := recover(); r != nil {
-			errAndWarnings = modconfig.NewErrorsAndWarning(helpers.ToError(r))
+			errorsAndWarnings = modconfig.NewErrorsAndWarning(helpers.ToError(r))
 		}
 	}()
 
-	mod, err := loadModDefinition(modPath, parseCtx)
-	if err != nil {
-		return nil, modconfig.NewErrorsAndWarning(err)
+	mod, loadModResult := loadModDefinition(modPath, parseCtx)
+	if loadModResult.Error != nil {
+		return nil, loadModResult
 	}
+
+	// apply opts to mod
+	for _, o := range opts {
+		o(mod)
+	}
+
+	// set the current mod on the run context
+	parseCtx.SetCurrentMod(mod)
+
 	// load the mod dependencies
 	if err := loadModDependencies(mod, parseCtx); err != nil {
 		return nil, modconfig.NewErrorsAndWarning(err)
 	}
-	// now we have loaded dependencies, set the current mod on the run context
-	parseCtx.CurrentMod = mod
+
 	// populate the resource maps of the current mod using the dependency mods
 	mod.ResourceMaps = parseCtx.GetResourceMaps()
-	// now load the mod resource hcl
-	return loadModResources(modPath, parseCtx)
+	// now load the mod resource hcl (
+	mod, errorsAndWarnings = loadModResources(mod, parseCtx)
+
+	// add in any warnings from mod load
+	errorsAndWarnings.AddWarning(loadModResult.Warnings...)
+	return mod, errorsAndWarnings
 }
 
-func loadModDefinition(modPath string, parseCtx *parse.ModParseContext) (*modconfig.Mod, error) {
-	var mod *modconfig.Mod
+func loadModDefinition(modPath string, parseCtx *parse.ModParseContext) (mod *modconfig.Mod, errorsAndWarnings *modconfig.ErrorAndWarnings) {
+	errorsAndWarnings = &modconfig.ErrorAndWarnings{}
 	// verify the mod folder exists
 	_, err := os.Stat(modPath)
 	if os.IsNotExist(err) {
-		return nil, fmt.Errorf("mod folder %s does not exist", modPath)
+		return nil, modconfig.NewErrorsAndWarning(fmt.Errorf("mod folder %s does not exist", modPath))
 	}
 
 	if parse.ModfileExists(modPath) {
 		// load the mod definition to get the dependencies
-		mod, err = parse.ParseModDefinition(modPath)
-		if err != nil {
-			return nil, err
+		var res *parse.DecodeResult
+		mod, res = parse.ParseModDefinition(modPath, parseCtx.EvalCtx)
+		errorsAndWarnings = modconfig.DiagsToErrorsAndWarnings("mod load failed", res.Diags)
+		if res.Diags.HasErrors() {
+			return nil, errorsAndWarnings
 		}
-		// now we have loaded the mod, if this is a dependency mod, add in any variables we have loaded
-		if parseCtx.ParentParseCtx != nil {
-			parseCtx.Variables = parseCtx.ParentParseCtx.DependencyVariables[mod.ShortName]
-			parseCtx.SetVariablesForDependencyMod(mod, parseCtx.ParentParseCtx.DependencyVariables)
-		}
-
 	} else {
 		// so there is no mod file - should we create a default?
 		if !parseCtx.ShouldCreateDefaultMod() {
+			errorsAndWarnings.Error = fmt.Errorf("mod folder %s does not contain a mod resource definition", modPath)
 			// ShouldCreateDefaultMod flag NOT set - fail
-			return nil, fmt.Errorf("mod folder %s does not contain a mod resource definition", modPath)
+			return nil, errorsAndWarnings
 		}
 		// just create a default mod
 		mod = modconfig.CreateDefaultMod(modPath)
 
 	}
-	return mod, nil
+	return mod, errorsAndWarnings
 }
 
 func loadModDependencies(mod *modconfig.Mod, parseCtx *parse.ModParseContext) error {
@@ -88,22 +97,15 @@ func loadModDependencies(mod *modconfig.Mod, parseCtx *parse.ModParseContext) er
 		}
 
 		for _, requiredModVersion := range mod.Require.Mods {
-			// if we have a locked version, update the required version to reflect this
-			lockedVersion, err := parseCtx.WorkspaceLock.GetLockedModVersionConstraint(requiredModVersion, mod)
+			// have we already loaded a mod which satisfied this
+			loadedMod, err := parseCtx.GetLoadedDependencyMod(requiredModVersion, mod)
 			if err != nil {
-				errors = append(errors, err)
+				return err
+			}
+			if loadedMod != nil {
 				continue
 			}
-			if lockedVersion != nil {
-				requiredModVersion = lockedVersion
-			}
 
-			// have we already loaded a mod which satisfied this
-			if loadedMod, ok := parseCtx.LoadedDependencyMods[requiredModVersion.Name]; ok {
-				if requiredModVersion.Constraint.Check(loadedMod.Version) {
-					continue
-				}
-			}
 			if err := loadModDependency(requiredModVersion, parseCtx); err != nil {
 				errors = append(errors, err)
 			}
@@ -124,7 +126,7 @@ func loadModDependency(modDependency *modconfig.ModVersionConstraint, parseCtx *
 	parentFolder := filepath.Dir(filepath.Join(parseCtx.WorkspaceLock.ModInstallationPath, modDependency.Name))
 
 	// search the parent folder for a mod installation which satisfied the given mod dependency
-	dependencyPath, version, err := findInstalledDependency(modDependency, parentFolder)
+	dependencyDir, version, err := findInstalledDependency(modDependency, parentFolder)
 	if err != nil {
 		return err
 	}
@@ -134,53 +136,39 @@ func loadModDependency(modDependency *modconfig.ModVersionConstraint, parseCtx *
 	parseCtx.ListOptions.Exclude = nil
 	defer func() { parseCtx.ListOptions.Exclude = prevExclusions }()
 
-	// create a child run context
-	childRunCtx := parse.NewModParseContext(
-		parseCtx.WorkspaceLock,
-		dependencyPath,
-		parse.CreatePseudoResources,
-		&filehelpers.ListOptions{
-			// listFlag specifies whether to load files recursively
-			Flags: filehelpers.FilesRecursive,
-			// only load .sp files
-			Include: filehelpers.InclusionsFromExtensions([]string{constants.ModDataExtension}),
-		})
-	childRunCtx.BlockTypes = parseCtx.BlockTypes
-	childRunCtx.ParentParseCtx = parseCtx
-
-	mod, errAndWarnings := LoadMod(dependencyPath, childRunCtx)
+	childParseCtx := parse.NewChildModParseContext(parseCtx, dependencyDir)
+	// NOTE: pass in the version and dependency path of the mod - these must be set before it loads its dependencies
+	mod, errAndWarnings := LoadMod(dependencyDir, childParseCtx, WithDependencyConfig(modDependency.Name, version))
 	if errAndWarnings.GetError() != nil {
 		return errAndWarnings.GetError()
 	}
 
-	// set the version and dependency path of the mod
-	mod.Version = version
-	mod.ModDependencyPath = modDependency.Name
-
 	// update loaded dependency mods
-	parseCtx.LoadedDependencyMods[modDependency.Name] = mod
+	parseCtx.AddLoadedDependencyMod(mod)
 	if parseCtx.ParentParseCtx != nil {
-		parseCtx.ParentParseCtx.LoadedDependencyMods[modDependency.Name] = mod
+		parseCtx.ParentParseCtx.AddLoadedDependencyMod(mod)
+		// add mod resources to parent parse context
+		parseCtx.ParentParseCtx.AddModResources(mod)
 	}
 
 	return nil
 
 }
 
-func loadModResources(modPath string, parseCtx *parse.ModParseContext) (*modconfig.Mod, *modconfig.ErrorAndWarnings) {
+func loadModResources(mod *modconfig.Mod, parseCtx *parse.ModParseContext) (*modconfig.Mod, *modconfig.ErrorAndWarnings) {
 	// if flag is set, create pseudo resources by mapping files
 	var pseudoResources []modconfig.MappableResource
 	var err error
 	if parseCtx.CreatePseudoResources() {
 		// now execute any pseudo-resource creations based on file mappings
-		pseudoResources, err = createPseudoResources(modPath, parseCtx)
+		pseudoResources, err = createPseudoResources(mod, parseCtx)
 		if err != nil {
 			return nil, modconfig.NewErrorsAndWarning(err)
 		}
 	}
 
 	// get the source files
-	sourcePaths, err := getSourcePaths(modPath, parseCtx.ListOptions)
+	sourcePaths, err := getSourcePaths(mod.ModPath, parseCtx.ListOptions)
 	if err != nil {
 		log.Printf("[WARN] LoadMod: failed to get mod file paths: %v\n", err)
 		return nil, modconfig.NewErrorsAndWarning(err)
@@ -192,20 +180,13 @@ func loadModResources(modPath string, parseCtx *parse.ModParseContext) (*modconf
 		return nil, modconfig.NewErrorsAndWarning(plugin.DiagsToError("Failed to load all mod files", diags))
 	}
 
-	// parse all hcl files.
+	// parse all hcl files (NOTE - this reads the CurrentMod out of ParseContext and adds to it)
 	mod, errAndWarnings := parse.ParseMod(fileData, pseudoResources, parseCtx)
-	if errAndWarnings.GetError() == nil {
-		// now add fully populated mod to the parent run context
-		if parseCtx.ParentParseCtx != nil {
-			parseCtx.ParentParseCtx.CurrentMod = mod
-			parseCtx.ParentParseCtx.AddMod(mod)
-		}
-	}
 
 	return mod, errAndWarnings
 }
 
-// search the parent folder for a mod installatio which satisfied the given mod dependency
+// search the parent folder for a mod installation which satisfied the given mod dependency
 func findInstalledDependency(modDependency *modconfig.ModVersionConstraint, parentFolder string) (string, *semver.Version, error) {
 	shortDepName := filepath.Base(modDependency.Name)
 	entries, err := os.ReadDir(parentFolder)
@@ -251,8 +232,7 @@ func findInstalledDependency(modDependency *modconfig.ModVersionConstraint, pare
 }
 
 // LoadModResourceNames parses all hcl files in modPath and returns the names of all resources
-func LoadModResourceNames(modPath string, parseCtx *parse.ModParseContext) (resources *modconfig.WorkspaceResources, err error) {
-	// TODO support dependencies
+func LoadModResourceNames(mod *modconfig.Mod, parseCtx *parse.ModParseContext) (resources *modconfig.WorkspaceResources, err error) {
 	defer func() {
 		if r := recover(); r != nil {
 			err = helpers.ToError(r)
@@ -264,12 +244,12 @@ func LoadModResourceNames(modPath string, parseCtx *parse.ModParseContext) (reso
 		parseCtx = &parse.ModParseContext{}
 	}
 	// verify the mod folder exists
-	if _, err := os.Stat(modPath); os.IsNotExist(err) {
-		return nil, fmt.Errorf("mod folder %s does not exist", modPath)
+	if _, err := os.Stat(mod.ModPath); os.IsNotExist(err) {
+		return nil, fmt.Errorf("mod folder %s does not exist", mod.ModPath)
 	}
 
 	// now execute any pseudo-resource creations based on file mappings
-	pseudoResources, err := createPseudoResources(modPath, parseCtx)
+	pseudoResources, err := createPseudoResources(mod, parseCtx)
 	if err != nil {
 		return nil, err
 	}
@@ -281,7 +261,7 @@ func LoadModResourceNames(modPath string, parseCtx *parse.ModParseContext) (reso
 		}
 	}
 
-	sourcePaths, err := getSourcePaths(modPath, parseCtx.ListOptions)
+	sourcePaths, err := getSourcePaths(mod.ModPath, parseCtx.ListOptions)
 	if err != nil {
 		log.Printf("[WARN] LoadModResourceNames: failed to get mod file paths: %v\n", err)
 		return nil, err
@@ -299,7 +279,7 @@ func LoadModResourceNames(modPath string, parseCtx *parse.ModParseContext) (reso
 	return resources.Merge(parsedResourceNames), nil
 }
 
-// GetModFileExtensions :: return list of all file extensions we care about
+// GetModFileExtensions returns list of all file extensions we care about
 // this will be the mod data extension, plus any registered extensions registered in fileToResourceMap
 func GetModFileExtensions() []string {
 	return append(modconfig.RegisteredFileExtensions(), constants.ModDataExtension, constants.VariablesExtension)
@@ -318,7 +298,7 @@ func getSourcePaths(modPath string, listOpts *filehelpers.ListOptions) ([]string
 }
 
 // create pseudo-resources for any files whose extensions are registered
-func createPseudoResources(modPath string, parseCtx *parse.ModParseContext) ([]modconfig.MappableResource, error) {
+func createPseudoResources(mod *modconfig.Mod, parseCtx *parse.ModParseContext) ([]modconfig.MappableResource, error) {
 	// create list options to find pseudo resources
 	listOpts := &filehelpers.ListOptions{
 		Flags:   parseCtx.ListOptions.Flags,
@@ -326,7 +306,7 @@ func createPseudoResources(modPath string, parseCtx *parse.ModParseContext) ([]m
 		Exclude: parseCtx.ListOptions.Exclude,
 	}
 	// list all registered files
-	sourcePaths, err := getSourcePaths(modPath, listOpts)
+	sourcePaths, err := getSourcePaths(mod.ModPath, listOpts)
 	if err != nil {
 		return nil, err
 	}
@@ -342,13 +322,13 @@ func createPseudoResources(modPath string, parseCtx *parse.ModParseContext) ([]m
 		if !ok {
 			continue
 		}
-		resource, fileData, err := factory(modPath, path, parseCtx.CurrentMod)
+		resource, fileData, err := factory(mod.ModPath, path, parseCtx.CurrentMod)
 		if err != nil {
 			errors = append(errors, err)
 			continue
 		}
 		if resource != nil {
-			metadata, err := getPseudoResourceMetadata(resource.Name(), path, fileData)
+			metadata, err := getPseudoResourceMetadata(mod, resource.Name(), path, fileData)
 			if err != nil {
 				return nil, err
 			}
@@ -367,7 +347,7 @@ func createPseudoResources(modPath string, parseCtx *parse.ModParseContext) ([]m
 	return res, nil
 }
 
-func getPseudoResourceMetadata(resourceName string, path string, fileData []byte) (*modconfig.ResourceMetadata, error) {
+func getPseudoResourceMetadata(mod *modconfig.Mod, resourceName string, path string, fileData []byte) (*modconfig.ResourceMetadata, error) {
 	sourceDefinition := string(fileData)
 	split := strings.Split(sourceDefinition, "\n")
 	lineCount := len(split)
@@ -386,6 +366,7 @@ func getPseudoResourceMetadata(resourceName string, path string, fileData []byte
 		IsAutoGenerated:  true,
 		SourceDefinition: sourceDefinition,
 	}
+	m.SetMod(mod)
 
 	return m, nil
 }
