@@ -12,6 +12,16 @@ module.exports = {
   core: {
     builder: "webpack5",
   },
+  typescript: {
+    check: false,
+    checkOptions: {},
+    reactDocgen: "react-docgen-typescript",
+    reactDocgenTypescriptOptions: {
+      shouldExtractLiteralValuesFromEnum: true,
+      propFilter: (prop) =>
+        prop.parent ? !/node_modules/.test(prop.parent.fileName) : true,
+    },
+  },
   webpackFinal: async (config) => {
     config = set(config, "resolve.fallback.fs", false);
     return config;
